@@ -71,6 +71,7 @@ import aws_cdk.aws_directoryservice._jsii
 import aws_cdk.aws_dlm._jsii
 import aws_cdk.aws_dms._jsii
 import aws_cdk.aws_docdb._jsii
+import aws_cdk.aws_docdbelastic._jsii
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecr._jsii
@@ -97,6 +98,7 @@ import aws_cdk.aws_fsx._jsii
 import aws_cdk.aws_gamelift._jsii
 import aws_cdk.aws_globalaccelerator._jsii
 import aws_cdk.aws_glue._jsii
+import aws_cdk.aws_grafana._jsii
 import aws_cdk.aws_greengrass._jsii
 import aws_cdk.aws_greengrassv2._jsii
 import aws_cdk.aws_groundstation._jsii
@@ -153,13 +155,17 @@ import aws_cdk.aws_neptune._jsii
 import aws_cdk.aws_networkfirewall._jsii
 import aws_cdk.aws_networkmanager._jsii
 import aws_cdk.aws_nimblestudio._jsii
+import aws_cdk.aws_oam._jsii
+import aws_cdk.aws_opensearchserverless._jsii
 import aws_cdk.aws_opensearchservice._jsii
 import aws_cdk.aws_opsworks._jsii
 import aws_cdk.aws_opsworkscm._jsii
+import aws_cdk.aws_organizations._jsii
 import aws_cdk.aws_panorama._jsii
 import aws_cdk.aws_personalize._jsii
 import aws_cdk.aws_pinpoint._jsii
 import aws_cdk.aws_pinpointemail._jsii
+import aws_cdk.aws_pipes._jsii
 import aws_cdk.aws_qldb._jsii
 import aws_cdk.aws_quicksight._jsii
 import aws_cdk.aws_ram._jsii
@@ -169,6 +175,7 @@ import aws_cdk.aws_redshiftserverless._jsii
 import aws_cdk.aws_refactorspaces._jsii
 import aws_cdk.aws_rekognition._jsii
 import aws_cdk.aws_resiliencehub._jsii
+import aws_cdk.aws_resourceexplorer2._jsii
 import aws_cdk.aws_resourcegroups._jsii
 import aws_cdk.aws_robomaker._jsii
 import aws_cdk.aws_rolesanywhere._jsii
@@ -182,6 +189,7 @@ import aws_cdk.aws_s3objectlambda._jsii
 import aws_cdk.aws_s3outposts._jsii
 import aws_cdk.aws_sagemaker._jsii
 import aws_cdk.aws_sam._jsii
+import aws_cdk.aws_scheduler._jsii
 import aws_cdk.aws_sdb._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_securityhub._jsii
@@ -213,9 +221,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.181.0",
+    "1.185.0",
     __name__[0:-6],
-    "cloudformation-include@1.181.0.jsii.tgz",
+    "cloudformation-include@1.185.0.jsii.tgz",
 )
 
 __all__ = [
